#!/bin/bash
#
##
# clpawsvip-watch.sh
##
# [coding：utf-8]
##


##
# function
##

# check awscli error message
function check_awscli_errmsg(){
	ERR_MSG=$*
	ERR_MSG="`echo \"${ERR_MSG}\" | grep A | grep error | grep operation:`"
	ERR_MSG="`echo \"${ERR_MSG}\" | sed -e \"s/A.* error .* operation: \(.*\)/\1/\"`"
	if [ -z "${ERR_MSG}" ]
	then
		clpshmrmset --descript --mon -t "${RESOURCE_TYPE}" -n "${RESOURCE_NAME}" -m "${AWSVIPW_ERR_AWSCLI_MSG}" > /dev/null 2>&1
		echo "do not output awscli error messages to alerts." 1>&2
	else
		ERRMSG_LEN=127
		ERR_MSG="`echo ${ERR_MSG:0:${ERRMSG_LEN}}`"
		clpshmrmset --descript --mon -t "${RESOURCE_TYPE}" -n "${RESOURCE_NAME}" -m "${ERR_MSG}" > /dev/null 2>&1
		echo "outputs awscli error messages to alerts." 1>&2
	fi
}

# clpcloudutil calls
CURRENT=$(cd $(dirname $0);pwd)
. "${CURRENT}/../common/clpcloudutil.sh"


##
# monitoring the clpawsvip
##

echo "clpawsvip watch script start."


##
# ret code
##
AWSVIPW_SUCCESS_CODE=0					# succeed
AWSVIPW_ERR_AWSCLI_CODE=50				# failed in the awscli command
AWSVIPW_ERR_SCHAWSCLI_CODE=51			# failed to search aws cli path
AWSVIPW_ERR_GETOCFENV_CODE=52			# failed to get the ocf environment variable
AWSVIPW_ERR_GETVIP_CODE=53				# get virtual ip has failed
AWSVIPW_ERR_GETVPCID_CODE=54			# get vpc id has failed
AWSVIPW_ERR_GETENIID_CODE=55			# get eni id has failed
AWSVIPW_ERR_CHKRT_CODE=56				# failed to check route table
AWSVIPW_ERR_CHKVIP_CODE=57				# failed to check virtual ip address

AWSVIPW_WARN_AWSCLI_CODE=150			# failed in the awscli command


##
# resultmsg
##
AWSVIPW_ERR_AWSCLI_MSG="Failed in the AWS CLI command."
AWSVIPW_ERR_SCHAWSCLI_MSG="The AWS CLI command is not found."
AWSVIPW_ERR_GETOCFENV_MSG="Failed to obtain the setting value."
AWSVIPW_ERR_GETVIP_MSG="Failed to obtain the virtual IP address."
AWSVIPW_ERR_GETVPCID_MSG="Failed to obtain the VPC ID."
AWSVIPW_ERR_GETENIID_MSG="Failed to obtain the ENI ID."
AWSVIPW_ERR_CHKRT_MSG="" #The routing for VIP ${VIRTUAL_IP} was changed.
AWSVIPW_ERR_CHKVIP_MSG="" #The VIP address ${VIRTUAL_IP} does not exist.


##
# set the value to use for the shmrmset command
##
RESOURCE_NAME="${CLP_RESOURCENAME}"		# resource name
RESOURCE_TYPE="awsvipw"					# resource type

if [ -z "${RESOURCE_NAME}" ]
then
	echo "failed to obtain the value required for the shmrmset command." 1>&2
fi


##
# awscli path
##
export PATH=$PATH:/usr/local/bin


##
# awscli path search
##
which aws > /dev/null 2>&1

if [ $? -ne 0 ]
then
	clpshmrmset --descript --mon -t "${RESOURCE_TYPE}" -n "${RESOURCE_NAME}" -m "${AWSVIPW_ERR_SCHAWSCLI_MSG}" > /dev/null 2>&1
	echo "failed to search aws cli path." 1>&2
	echo "clpawsvip watch script has failed." 1>&2
	exit ${AWSVIPW_ERR_SCHAWSCLI_CODE}
fi


##
# set environment variables for use with the aws cli
##
clpcloudutil_env_init "${clpcloudutil_false}" "${CURRENT}/clpaws_setting.conf"


##
# get aws cli command line options
##
EC2_CMDOPT="`clpcloudutil_awscli_cmdopt \"${clpcloudutil_false}\" ec2`"


##
# set ocf environment variable
##
TARGET_RSC="${CLP_OCF_PARAM1}"			# resource name
MON_MODE="${CLP_OCF_PARAM2}"			# action when aws cli command failed to receive response
PING_TIMEOUT="${CLP_OCF_PARAM3}"		# ping timeout

if [ -z "${TARGET_RSC}" ] || [ -z "${MON_MODE}" ] || [ -z "${PING_TIMEOUT}" ]
then
	clpshmrmset --descript --mon -t "${RESOURCE_TYPE}" -n "${RESOURCE_NAME}" -m "${AWSVIPW_ERR_GETOCFENV_MSG}" > /dev/null 2>&1
	echo "failed to get the ocf environment variable." 1>&2
	echo "clpawsvip watch script has failed." 1>&2
	exit ${AWSVIPW_ERR_GETOCFENV_CODE}
fi


##
# set server name
##
SRV_FULLNAME="`uname -n`"				# get hostname (use output file path)
SRV_NAME="`echo ${SRV_FULLNAME%%.*}`"	# delete domain name


##
# get target resource config
##
VIRTUAL_IP="`clpcfget -g /root/resource/awsvip@\"${TARGET_RSC}\"/parameters/ip -p awsvip`"
if [ $? -ne 0 ]
then
	clpshmrmset --descript --mon -t "${RESOURCE_TYPE}" -n "${RESOURCE_NAME}" -m "${AWSVIPW_ERR_GETVIP_MSG}" > /dev/null 2>&1
	echo "${VIRTUAL_IP}" | head -n 1 1>&2
	echo "get virtual ip has failed." 1>&2
	echo "clpawsvip watch script has failed." 1>&2
	exit ${AWSVIPW_ERR_GETVIP_CODE}
fi

VPC_ID="`clpcfget -g /root/resource/awsvip@\"${TARGET_RSC}\"/parameters/vpcid -p awsvip -s \"${SRV_NAME}\"`"
if [ $? -ne 0 ]
then
	clpshmrmset --descript --mon -t "${RESOURCE_TYPE}" -n "${RESOURCE_NAME}" -m "${AWSVIPW_ERR_GETVPCID_MSG}" > /dev/null 2>&1
	echo "${VPC_ID}" | head -n 1 1>&2
	echo "get vpc id has failed." 1>&2
	echo "clpawsvip watch script has failed." 1>&2
	exit ${AWSVIPW_ERR_GETVPCID_CODE}
fi

ENI_ID="`clpcfget -g /root/resource/awsvip@\"${TARGET_RSC}\"/parameters/eniid -p awsvip -s \"${SRV_NAME}\"`"
if [ $? -ne 0 ]
then
	clpshmrmset --descript --mon -t "${RESOURCE_TYPE}" -n "${RESOURCE_NAME}" -m "${AWSVIPW_ERR_GETENIID_MSG}" > /dev/null 2>&1
	echo "${ENI_ID}" | head -n 1 1>&2
	echo "get eni id has failed." 1>&2
	echo "clpawsvip watch script has failed." 1>&2
	exit ${AWSVIPW_ERR_GETENIID_CODE}
fi

echo "get config has succeeded. (vip=${VIRTUAL_IP} vpcid=${VPC_ID} eniid=${ENI_ID})"


##
# check route table
##
CIDR_BLOCK="/32"
VIP_CIDR_BLOCK="$VIRTUAL_IP$CIDR_BLOCK"

CHG_RT_IDLIST=$(aws ec2 describe-route-tables \
	--filters "Name=vpc-id,Values=${VPC_ID}" "Name=route.destination-cidr-block,Values=${VIP_CIDR_BLOCK}" \
		--query "RouteTables[?contains(Routes[?DestinationCidrBlock=='${VIP_CIDR_BLOCK}'].NetworkInterfaceId,'${ENI_ID}')==\`false\`].RouteTableId" ${EC2_CMDOPT} --output json 2>&1)
if [ $? -ne 0 ]
then
	echo "${CHG_RT_IDLIST}"
	check_awscli_errmsg "${CHG_RT_IDLIST}"
	echo "failed to check route table." 1>&2
	echo "clpawsvip watch script has failed." 1>&2
	case ${MON_MODE} in
		0 ) exit ${AWSVIPW_SUCCESS_CODE} ;;
		1 ) exit ${AWSVIPW_WARN_AWSCLI_CODE} ;;
		2 ) exit ${AWSVIPW_ERR_AWSCLI_CODE} ;;
	esac
elif [ "${CHG_RT_IDLIST}" != "[]" ]
then
	AWSVIPW_ERR_CHKRT_MSG="The routing for VIP \"${VIRTUAL_IP}\" was changed."
	clpshmrmset --descript --mon -t "${RESOURCE_TYPE}" -n "${RESOURCE_NAME}" -m "${AWSVIPW_ERR_CHKRT_MSG}" > /dev/null 2>&1
	echo "vip ${VIRTUAL_IP} route of ${CHG_RT_IDLIST} is changed." 1>&2
	echo "clpawsvip watch script has failed." 1>&2
	exit ${AWSVIPW_ERR_CHKRT_CODE}
fi

echo "check route table has succeeded."


##
# check virtual ip exists
##
clpping -c ${PING_TIMEOUT} "${VIRTUAL_IP}" > /dev/null 2>&1
if [ $? -ne 0 ]
then
	AWSVIPW_ERR_CHKVIP_MSG="The VIP address \"${VIRTUAL_IP}\" does not exist."
	clpshmrmset --descript --mon -t "${RESOURCE_TYPE}" -n "${RESOURCE_NAME}" -m "${AWSVIPW_ERR_CHKVIP_MSG}" > /dev/null 2>&1
	echo "failed to check virtual ip address." 1>&2
	echo "clpawsvip watch script has failed." 1>&2
	exit ${AWSVIPW_ERR_CHKVIP_CODE}
fi


##
# end
##
echo "clpawsvip watch script has succeeded."

exit ${AWSVIPW_SUCCESS_CODE}

