#!/bin/bash

#
#  usage : clpazureforcestop.sh <sub-command> <option>
#
#  sub-command :
#         stop       <vm_name> <rsc_grp> <user_uri> <tenant_id> <cert_file> <fst_mode>
#         check-stop <vm_name> <rsc_grp> <user_uri> <tenant_id> <cert_file>
#         monitor    <vm_name> <rsc_grp> <user_uri> <tenant_id> <cert_file>
#

sub_cmd="$1"
vm_name="$2"
rsc_grp="$3"
user_uri="$4"
tenant_id="$5"
cert_file="$6"
fst_mode="$7"

function login_cli()
{
    if ! az login --service-principal -u "${user_uri}" -p "${cert_file}" --tenant "${tenant_id}" >/dev/null; then
        exit 1
    fi
}

function exec_cmd()
{
    local cmdline=$1
    local result
    if ! result=$(eval "${cmdline}"); then
        # azコマンド実行直前に異なるプロセスでaz cliログアウト処理が行われる可能性があるため
        # azコマンド失敗時はaz cli再ログイン後にリトライを試みる
        # なお、本スクリプトではaz cliログアウト処理は行わない
        login_cli
        if ! result=$(eval "${cmdline}"); then
            echo "'${cmdline}' was re-run but failed." 1>&2
            exit 1
        fi
    fi
    echo "${result}"
}


# 'az'コマンドの存在確認
if ! which az >/dev/null 2>&1; then
    echo "The 'az' command does not exist." 1>&2
    exit 1
fi

# az cliログイン(初回)
login_cli

# 強制停止(stop)
if [ "${sub_cmd}" == "stop" ] && [ "${fst_mode}" == "stop" ]; then
    cmdline="az vm deallocate -g ${rsc_grp} -n ${vm_name} --no-wait"
    exec_cmd "${cmdline}" >/dev/null

# 強制停止(reboot)
elif [ "${sub_cmd}" == "stop" ] && [ "${fst_mode}" == "reboot" ]; then
    cmdline="az vm restart -g ${rsc_grp} -n ${vm_name}  --no-wait --force"
    exec_cmd "${cmdline}" >/dev/null

# 強制停止完了確認
elif [ "${sub_cmd}" == "check-stop" ]; then
    cmdline="az vm get-instance-view -g ${rsc_grp} -n ${vm_name} --query instanceView.statuses[1].displayStatus --output tsv"
    status=$(exec_cmd "${cmdline}") || exit 1
    if [ "${status}" != "VM deallocated" ]; then
        echo "Virtual machine is not in 'VM deallocated' state. status(${status})" 1>&2
        exit 1
    fi

# 強制停止定期確認
elif [ "${sub_cmd}" == "monitor" ]; then
    cmdline="az vm update -g ${rsc_grp} -n ${vm_name} --no-wait"
    exec_cmd "${cmdline}" >/dev/null

    cmdline="az vm get-instance-view -g ${rsc_grp} -n ${vm_name}"
    exec_cmd "${cmdline}" >/dev/null

# bug
else
    echo "Invalid arguments. sub_cmd(${sub_cmd}), fst_mode(${fst_mode})" 1>&2
    exit 1
fi

exit 0
